@@ -29,7 +29,7 @@ df = model.matrix(~X1+X2+cc, data=sample_data$pred)
 head(df)
 
 ## ----echo=TRUE----------------------------------------------------------------
-re = nebula(sample_data$count,sample_data$sid,pred=df)
+re = nebula(sample_data$count,sample_data$sid,pred=df,ncore=2)
 re
 
 ## ----eval=FALSE,echo=TRUE-----------------------------------------------------
@@ -37,7 +37,9 @@ re
 #  re = nebula(data_g$count,data_g$id,pred=data_g$pred)
 
 ## ----eval=FALSE,echo=TRUE-----------------------------------------------------
-#  re = nebula(sample_data$count,sample_data$sid,pred=df,offset=sample_data$offset)
+#  library(Matrix)
+#  # An example of using the library size of each cell as the scaling factor
+#  re = nebula(sample_data$count,sample_data$sid,pred=df,offset=Matrix::colSums(sample_data$count))
 
 ## ----eval=TRUE,echo=TRUE------------------------------------------------------
 re_ln = nebula(sample_data$count,sample_data$sid,pred=df,offset=sample_data$offset,method='LN')
@@ -55,6 +57,9 @@ re = nebula(sample_data$count,sample_data$sid,pred=df,offset=sample_data$offset,
 ## ----echo=FALSE,results='asis'------------------------------------------------
 knitr::kable(re$summary)
 
+## ----eval=TRUE,echo=TRUE------------------------------------------------------
+re = nebula(sample_data$count,sample_data$sid,pred=df,offset=sample_data$offset,model='NBLMM',reml=1)
+
 ## ----eval=TRUE,echo=TRUE------------------------------------------------------
 df = model.matrix(~X1+X2+cc, data=sample_data$pred)
 re_ln = nebula(sample_data$count,sample_data$sid,pred=df,offset=sample_data$offset,method='LN',covariance=TRUE)
